/// Copyright (c) 2022 Ivan Territo
///
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
///
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
///
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

import 'package:buttons_showcase/buttons_showcase.dart';
import 'package:example/pages/page_social.dart';
import 'package:flutter/material.dart';
import 'package:example/widgets/divider_header.dart';
import 'package:buttons_showcase/utils/list_social.dart';
import 'package:buttons_showcase/models/social.dart';

/// Homepage used to show all different possibilities.
/// Widgets are created using the buildList() function
class Homepage extends StatefulWidget {
  const Homepage({Key? key}) : super(key: key);

  @override
  State<Homepage> createState() => _HomepageState();
}

class _HomepageState extends State<Homepage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          Container(
            width: double.infinity,
            alignment: Alignment.center,
            child: const Padding(
              padding: EdgeInsets.only(bottom: 16, top: 46),
              child: Text('Buttons Showcase', style: TextStyle(color: Colors.white, fontWeight: FontWeight.w300, fontSize: 28)),
            ),
            decoration: BoxDecoration(
              color: Colors.pink,
              boxShadow: [
                BoxShadow(
                  color: Colors.grey.withOpacity(0.5),
                  spreadRadius: 5,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
          ),
          Expanded(
            child: ListView(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 8),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Divider_Header("Social buttons:"),
                      const SizedBox(height: 8),
                      ...buildList()
                    ]
                  ),
                )
              ],
            ),
          ),
        ],
      ),
    );
  }

  List<Widget> buildList() {
    List<Widget> list = [];
    listSocial.forEach((key, social) {
      list.add(
        Column(
          children: [
            const SizedBox(height: 8),
            BaseButton(size: "M", function: () => {goTo(social, key)}, social: listSocial[key]!),
            const SizedBox(height: 16),
          ],
        )
      );
    });
    return list;
  }

  goTo(Social social, String key) {
    Navigator.push(
      context,
      MaterialPageRoute(builder: (context) => PageSocial(social, key)),
    );
  }
}