/// Copyright (c) 2022 Ivan Territo
///
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
///
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
///
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

import 'package:flutter/material.dart';
import 'package:buttons_showcase/buttons_showcase.dart';
import 'package:example/widgets/divider_header.dart';
import 'package:buttons_showcase/utils/list_social.dart';
import 'package:buttons_showcase/models/social.dart';

import 'homepage.dart';

/// Singular "social" page with all possible cases for that Color / brand
class PageSocial extends StatelessWidget {
  PageSocial(this.social, this.keyword, {Key? key}) : super(key: key);

  Social social;
  String keyword;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: [
          Container(
            width: double.infinity,
            alignment: Alignment.center,
            padding: const EdgeInsets.only(bottom: 16, top: 46),
            child: Stack(
              children: [
                Align(alignment: Alignment.centerLeft, child: GestureDetector(
                  onTap: () => { goHome(context) },
                  child: Padding(
                    padding: const EdgeInsets.symmetric(horizontal: 8),
                    child: Icon(Icons.chevron_left, color: social.textColor, size: 32),
                  ),
                )),
                Align(alignment: Alignment.center, child: Text('${social.name} Style', style: TextStyle(fontWeight: FontWeight.w300, fontSize: 28, color: social.textColor)))
              ],
            ),
            decoration: BoxDecoration(
              boxShadow: [
                BoxShadow(
                  color: Colors.grey.withOpacity(0.5),
                  spreadRadius: 5,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
              ],
              color: social.color,
            ),
          ),
          Expanded(
            child: ListView(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 8),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      /// List of the all possibilities
                      // SIZES SECTION
                      Divider_Header("S, M and L sizes:"),
                      const SizedBox(height: 8),
                      BaseButton(size: "S", social: listSocial[keyword]!),
                      const SizedBox(height: 4),
                      BaseButton(size: "M", social: listSocial[keyword]!),
                      const SizedBox(height: 4),
                      BaseButton(size: "L", social: listSocial[keyword]!),
                      const SizedBox(height: 32),
                      // MANAGE THE LOGO SECTION
                      Divider_Header("Manage the logo:"),
                      const SizedBox(height: 8),
                      BaseButton(showLogo: false, social: listSocial[keyword]!),
                      ...buildLogoSection(),
                      const SizedBox(height: 32),
                      // MANAGE THE TEXT SECTION
                      Divider_Header("Manage the text:"),
                      const SizedBox(height: 8),
                      BaseButton(customText: "Your custom text", social: listSocial[keyword]!),
                      const SizedBox(height: 32),
                      // MANAGE THE SHAPE SECTION
                      Divider_Header("Manage the shape:"),
                      const SizedBox(height: 8),
                      BaseButton(customShape: "circle", social: listSocial[keyword]!),
                      const SizedBox(height: 8),
                      BaseButton(customShape: "square", iconType: 1, social: listSocial[keyword]!)
                    ],
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  buildLogoSection() {
    List<Widget> list = [];
    listSocial[keyword]!.logoPaths.toList().asMap().forEach((index, el) {
      list.add(
          Column(
            children: [
              const SizedBox(height: 8),
              BaseButton(iconType: index, social: listSocial[keyword]!),
            ],
          )
      );
    });
    return list;
  }

  goHome(context) {
    Navigator.push(
      context,
      MaterialPageRoute(builder: (context) => const Homepage()),
    );
  }
}
