/// Copyright (c) 2022 Ivan Territo
///
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
///
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
///
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

library buttons_showcase;

import 'package:flutter/material.dart';
import 'models/social.dart';
import 'widgets/rounded_btn.dart';

/// Buttons base class with all the customizable parameters in it
class BaseButton extends StatelessWidget {
  const BaseButton({
    this.textCaps = false,
    this.showLogo = true,
    this.customText,
    this.size = "M",
    this.iconType = 0,
    this.customShape,
    this.function,
    required this.social,
    Key? key
  }) : super(key: key);

  final bool? textCaps, showLogo;
  final String? customText, customShape, size;
  final int? iconType;
  final Social social;
  final Function? function;

  @override
  Widget build(BuildContext context) {
    String text = "Log in with ${social.name}";
    double? width, height, fontSize, iconSize;
    String iconPath = social.logoPaths[0];
    if(customText != null) text = customText!;
    if(textCaps!) text = text.toUpperCase();
    if(iconType != null) {
      if(social.logoPaths.length > iconType!) {
        iconPath = social.logoPaths[iconType!];
      }
    }
    if(size != null) {
      switch(size) {
        case "S": width = 220; height = 40; fontSize = 16; iconSize = 20; break;
        case "M": width = 260; height = 56; fontSize = 18; iconSize = 28; break;
        case "L": width = 320; height = 72; fontSize = 24; iconSize = 36; break;
        default: width = 260; height = 56; fontSize = 18; iconSize = 28; break;
      }
    }

    return GestureDetector(
      onTap: () => function != null ? function!() : {
        ScaffoldMessenger.of(context).showSnackBar(
          const SnackBar(
            content: Text("Pass your 'function' parameter"),
          )
        )
      },
      child: RoundedButton(
          Padding(
            padding: EdgeInsets.all(customShape == null ? 8 : 0),
            child: Row(
              mainAxisAlignment: customShape == null ? MainAxisAlignment.start : MainAxisAlignment.center,
              children: [
                if(showLogo!) Image(
                    image: AssetImage(iconPath, package: 'buttons_showcase'),
                    color: social.textColor,
                    width: iconSize
                ),
                if(customShape == null) const SizedBox(width: 8),
                if(customShape == null) Text(
                    text,
                    style: TextStyle(color: social.textColor, fontSize: fontSize)
                ),
              ],
            ),
          ),
          width: width!,
          height: height!,
          backgroundColor: social.color,
          borderRadius: 5,
          customShape: customShape
      ),
    );
  }
}