/// Copyright (c) 2022 Ivan Territo
///
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
///
/// The above copyright notice and this permission notice shall be included in all
/// copies or substantial portions of the Software.
///
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
/// SOFTWARE.

import 'package:flutter/material.dart';

/// Class used to provide a basic shape for each button
class RoundedButton extends StatelessWidget {
  const RoundedButton(
    this.child,
    {
      this.width = 260,
      this.height = 28,
      this.borderRadius = 20,
      this.backgroundColor = Colors.transparent,
      this.customShape,
      Key? key
    }
  ) : super(key: key);

  final Widget child;
  final double width, height, borderRadius;
  final Color backgroundColor;
  final String? customShape;

  @override
  Widget build(BuildContext context) {
    /// Case of normal button, so rectangular
    if(customShape == null) {
      return Container(
        width: width,
        height: height,
        decoration: BoxDecoration(
          color: backgroundColor,
          border: Border.all(
            color: backgroundColor,
          ),
          borderRadius: BorderRadius.all(Radius.circular(borderRadius))
        ),
        child: child
      );
    } else {
      /// Case for not normal and rectangular button, so Square or Circle
      switch(customShape!.toLowerCase()) {
        case "square": return Container(
            width: height,
            height: height,
            decoration: BoxDecoration(
              color: backgroundColor,
              borderRadius: BorderRadius.all(Radius.circular(borderRadius))
            ),
            child: child
        );
        default: return Container(
            width: height,
            height: height,
            decoration: BoxDecoration(
              color: backgroundColor,
              borderRadius: const BorderRadius.all(Radius.circular(90))
            ),
            child: child
        );
      }
    }
  }
}
